[−][src]Function proj17_iot_server::endpoints::devices_endpoints::get_tracker
pub fn get_tracker(
tracker_id: String
) -> Option<Result<JsonValue, &'static str>>
Responds with the receiver if any a tracker is registered at.
Responds with:
- 200: if the tracker and the receiver exist
- 404: if either the receiver or tracker does not exist
This is an API endpoint mapped to
- /trackers/<tracker_id> [GET]
Arguments
tracker_id- an identifier String of a tracker