[−][src]Function proj17_iot_server::endpoints::devices_endpoints::register
pub fn register(station_id: String, tracker_id: String) -> Option<JsonValue>
Registers a specified tracker from a specified receiver, granted both exist.
Responds with:
- 200: if the tracker and receiver exist.
- 404: if either the receiver or tracker does not exist
This is an API endpoint mapped to
- /register/<station_id>/<tracker_id> [POST]
Arguments
station_id- an identifier String of a receivertracker_id- an identifier String of a tracker