[][src]Function proj17_iot_server::endpoints::devices_endpoints::register_json

pub fn register_json(body: Json<RegisterBody>) -> Option<JsonValue>

Registers a specified tracker from a specified receiver, granted both exist, where the arguments are given as request body.

Responds with:

This is an API endpoint mapped to

Arguments

{ loc: <receiver_id>, tag: <tracker_id> }