[−][src]Function proj17_iot_server::endpoints::devices_endpoints::unregister
pub fn unregister(
station_id: String,
tracker_id: String
) -> Result<JsonValue, Option<JsonValue>>
Unregisters a specified tracker from a specified receiver. If the tracker is not currently registered to this receiver, this call will have no effect.
Responds with:
- 200: if the tracker and receiver exist.
- 404: if either the receiver or tracker does not exist
This is an API endpoint mapped to
- /unregister/<station_id>/<tracker_id> [POST]
Arguments
station_id- an identifier String of a receivertracker_id- an identifier String of a tracker