[][src]Function proj17_iot_server::persistance::db::find_eligible_videos_by_interest

pub fn find_eligible_videos_by_interest(
    interests: Vec<i32>
) -> Result<Option<Vec<AdvertVideoOrder>>, String>

Returns all elligible videos for the interests contained in the Vec interests with interest_id's. Only returns videos that are payed for, and matches one of the interests given

Arguments

interests - A vector of integers representing interests