[][src]Function proj17_iot_server::persistance::db::get_interests_at_location

pub fn get_interests_at_location(
    location: i32
) -> Result<Option<Vec<(i32, f32)>>, String>

Returns the aggregated weight of all the interests for trackers in this location and turns into a reverse weight sorted tuple of (interest, weight).

Arguments

location - an i32 representing a physical location